@@ -12,7 +12,7 @@ use feature ();
 package Zydeco;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.607';
+our $VERSION   = '0.608';
 
 use Keyword::Simple ();
 use PPR;
@@ -315,7 +315,7 @@ our $GRAMMAR = qr{
 				(?&PerlBlock) | (?&PerlQualifiedIdentifier)
 			)
 			(?:
-				(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlList) [)] )
+				(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlOWS) (?&PerlList) (?&PerlOWS) [)] )
 			)?
 			(?:
 				(?&PerlOWS)
@@ -325,7 +325,7 @@ our $GRAMMAR = qr{
 					(?&PerlBlock) | (?&PerlQualifiedIdentifier)
 				)
 				(?:
-					(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlList) [)] )
+					(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlOWS) (?&PerlList) (?&PerlOWS) [)] )
 				)?
 			)*
 		)#</MxpRoleList>
@@ -337,7 +337,7 @@ our $GRAMMAR = qr{
 				(?&PerlQualifiedIdentifier)
 			)
 			(?:
-				(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlList) [)] )
+				(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlOWS) (?&PerlList) (?&PerlOWS) [)] )
 			)?
 			(?:
 				(?&PerlOWS)
@@ -347,7 +347,7 @@ our $GRAMMAR = qr{
 					(?&PerlQualifiedIdentifier)
 				)
 				(?:
-					(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlList) [)] )
+					(?:\s*\?) | (?: (?&PerlOWS) [(] (?&PerlOWS) (?&PerlList) (?&PerlOWS) [)] )
 				)?
 			)*
 		)#</MxpCompactRoleList>
@@ -973,7 +973,7 @@ sub _handle_role_list {
 			$suffix = '?';
 			$rolelist =~ s/^\?\s*//xs;
 		}
-		elsif ($rolelist =~ /^((?&PerlList)) $GRAMMAR/xso) {
+		elsif ($rolelist =~ /^((?&PerlOWS)(?&PerlList)(?&PerlOWS)) $GRAMMAR/xso) {
 			$role_params = $1;
 			$rolelist =~ s/^\Q$role_params//xs;
 			$rolelist =~ s/^\s+//xs;
@@ -2327,7 +2327,7 @@ sub _include {
 #{
 #	package Zydeco::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.607';
+#	our $VERSION   = '0.608';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -2338,7 +2338,7 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.607';
+#	our $VERSION   = '0.608';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -2351,12 +2351,12 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.607';
+#	our $VERSION   = '0.608';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	
 #	package Zydeco::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.607';
+#	our $VERSION   = '0.608';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2370,7 +2370,7 @@ sub _include {
 #
 #	package Zydeco::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.607';
+#	our $VERSION   = '0.608';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
